[svn-commits] kmoore: branch kmoore/stasis_http_rename r395529 - in /team/kmoore/stasis_htt...

SVN commits to the Digium repositories svn-commits at lists.digium.com
Fri Jul 26 12:59:20 CDT 2013


Author: kmoore
Date: Fri Jul 26 12:59:18 2013
New Revision: 395529

URL: http://svnview.digium.com/svn/asterisk?view=rev&rev=395529
Log:
Fix stub generation by renaming templates and regenerate stubs

Added:
    team/kmoore/stasis_http_rename/rest-api-templates/ari.make.mustache
      - copied unchanged from r395528, team/kmoore/stasis_http_rename/rest-api-templates/stasis_http.make.mustache
    team/kmoore/stasis_http_rename/rest-api-templates/ari_resource.c.mustache
      - copied unchanged from r395528, team/kmoore/stasis_http_rename/rest-api-templates/stasis_http_resource.c.mustache
    team/kmoore/stasis_http_rename/rest-api-templates/ari_resource.h.mustache
      - copied unchanged from r395528, team/kmoore/stasis_http_rename/rest-api-templates/stasis_http_resource.h.mustache
    team/kmoore/stasis_http_rename/rest-api-templates/res_ari_resource.c.mustache
      - copied unchanged from r395528, team/kmoore/stasis_http_rename/rest-api-templates/res_stasis_http_resource.c.mustache
Removed:
    team/kmoore/stasis_http_rename/rest-api-templates/res_stasis_http_resource.c.mustache
    team/kmoore/stasis_http_rename/rest-api-templates/stasis_http.make.mustache
    team/kmoore/stasis_http_rename/rest-api-templates/stasis_http_resource.c.mustache
    team/kmoore/stasis_http_rename/rest-api-templates/stasis_http_resource.h.mustache
Modified:
    team/kmoore/stasis_http_rename/res/ari.make
    team/kmoore/stasis_http_rename/res/ari/resource_asterisk.h
    team/kmoore/stasis_http_rename/res/ari/resource_bridges.h
    team/kmoore/stasis_http_rename/res/ari/resource_channels.h
    team/kmoore/stasis_http_rename/res/ari/resource_endpoints.h
    team/kmoore/stasis_http_rename/res/ari/resource_events.h
    team/kmoore/stasis_http_rename/res/ari/resource_playback.h
    team/kmoore/stasis_http_rename/res/ari/resource_recordings.h
    team/kmoore/stasis_http_rename/res/ari/resource_sounds.h
    team/kmoore/stasis_http_rename/res/res_ari_asterisk.c
    team/kmoore/stasis_http_rename/res/res_ari_bridges.c
    team/kmoore/stasis_http_rename/res/res_ari_channels.c
    team/kmoore/stasis_http_rename/res/res_ari_endpoints.c
    team/kmoore/stasis_http_rename/res/res_ari_events.c
    team/kmoore/stasis_http_rename/res/res_ari_playback.c
    team/kmoore/stasis_http_rename/res/res_ari_recordings.c
    team/kmoore/stasis_http_rename/res/res_ari_sounds.c

Modified: team/kmoore/stasis_http_rename/res/ari.make
URL: http://svnview.digium.com/svn/asterisk/team/kmoore/stasis_http_rename/res/ari.make?view=diff&rev=395529&r1=395528&r2=395529
==============================================================================
--- team/kmoore/stasis_http_rename/res/ari.make (original)
+++ team/kmoore/stasis_http_rename/res/ari.make Fri Jul 26 12:59:18 2013
@@ -1,7 +1,7 @@
 #
 # Asterisk -- A telephony toolkit for Linux.
 #
-# Generated Makefile for res_stasis_http dependencies.
+# Generated Makefile for res_ari dependencies.
 #
 # Copyright (C) 2013, Digium, Inc.
 #
@@ -14,38 +14,38 @@
 # !!!!!                               DO NOT EDIT                        !!!!!
 # !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 # This file is generated by a template. Please see the original template at
-# rest-api-templates/stasis_http.make.mustache
+# rest-api-templates/ari.make.mustache
 #
 
-res_stasis_http_asterisk.so: stasis_http/resource_asterisk.o
+res_ari_asterisk.so: ari/resource_asterisk.o
 
-stasis_http/resource_asterisk.o: _ASTCFLAGS+=$(call MOD_ASTCFLAGS,res_stasis_http_asterisk)
+ari/resource_asterisk.o: _ASTCFLAGS+=$(call MOD_ASTCFLAGS,res_ari_asterisk)
 
-res_stasis_http_endpoints.so: stasis_http/resource_endpoints.o
+res_ari_endpoints.so: ari/resource_endpoints.o
 
-stasis_http/resource_endpoints.o: _ASTCFLAGS+=$(call MOD_ASTCFLAGS,res_stasis_http_endpoints)
+ari/resource_endpoints.o: _ASTCFLAGS+=$(call MOD_ASTCFLAGS,res_ari_endpoints)
 
-res_stasis_http_channels.so: stasis_http/resource_channels.o
+res_ari_channels.so: ari/resource_channels.o
 
-stasis_http/resource_channels.o: _ASTCFLAGS+=$(call MOD_ASTCFLAGS,res_stasis_http_channels)
+ari/resource_channels.o: _ASTCFLAGS+=$(call MOD_ASTCFLAGS,res_ari_channels)
 
-res_stasis_http_bridges.so: stasis_http/resource_bridges.o
+res_ari_bridges.so: ari/resource_bridges.o
 
-stasis_http/resource_bridges.o: _ASTCFLAGS+=$(call MOD_ASTCFLAGS,res_stasis_http_bridges)
+ari/resource_bridges.o: _ASTCFLAGS+=$(call MOD_ASTCFLAGS,res_ari_bridges)
 
-res_stasis_http_recordings.so: stasis_http/resource_recordings.o
+res_ari_recordings.so: ari/resource_recordings.o
 
-stasis_http/resource_recordings.o: _ASTCFLAGS+=$(call MOD_ASTCFLAGS,res_stasis_http_recordings)
+ari/resource_recordings.o: _ASTCFLAGS+=$(call MOD_ASTCFLAGS,res_ari_recordings)
 
-res_stasis_http_sounds.so: stasis_http/resource_sounds.o
+res_ari_sounds.so: ari/resource_sounds.o
 
-stasis_http/resource_sounds.o: _ASTCFLAGS+=$(call MOD_ASTCFLAGS,res_stasis_http_sounds)
+ari/resource_sounds.o: _ASTCFLAGS+=$(call MOD_ASTCFLAGS,res_ari_sounds)
 
-res_stasis_http_playback.so: stasis_http/resource_playback.o
+res_ari_playback.so: ari/resource_playback.o
 
-stasis_http/resource_playback.o: _ASTCFLAGS+=$(call MOD_ASTCFLAGS,res_stasis_http_playback)
+ari/resource_playback.o: _ASTCFLAGS+=$(call MOD_ASTCFLAGS,res_ari_playback)
 
-res_stasis_http_events.so: stasis_http/resource_events.o
+res_ari_events.so: ari/resource_events.o
 
-stasis_http/resource_events.o: _ASTCFLAGS+=$(call MOD_ASTCFLAGS,res_stasis_http_events)
+ari/resource_events.o: _ASTCFLAGS+=$(call MOD_ASTCFLAGS,res_ari_events)
 

Modified: team/kmoore/stasis_http_rename/res/ari/resource_asterisk.h
URL: http://svnview.digium.com/svn/asterisk/team/kmoore/stasis_http_rename/res/ari/resource_asterisk.h?view=diff&rev=395529&r1=395528&r2=395529
==============================================================================
--- team/kmoore/stasis_http_rename/res/ari/resource_events.h (original)
+++ team/kmoore/stasis_http_rename/res/ari/resource_events.h Fri Jul 26 12:59:18 2013
@@ -19,7 +19,7 @@
 /*! \file
  *
  * \brief Generated file - declares stubs to be implemented in
- * res/stasis_http/resource_events.c
+ * res/ari/resource_events.c
  *
  * WebSocket resource
  *
@@ -31,15 +31,15 @@
  * !!!!!                               DO NOT EDIT                        !!!!!
  * !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
  * This file is generated by a mustache template. Please see the original
- * template in rest-api-templates/stasis_http_resource.h.mustache
+ * template in rest-api-templates/ari_resource.h.mustache
  */
 
 #ifndef _ASTERISK_RESOURCE_EVENTS_H
 #define _ASTERISK_RESOURCE_EVENTS_H
 
-#include "asterisk/stasis_http.h"
+#include "asterisk/ari.h"
 
-/*! \brief Argument struct for stasis_http_event_websocket() */
+/*! \brief Argument struct for ari_event_websocket() */
 struct ast_event_websocket_args {
 	/*! \brief Comma seperated list of applications to subscribe to. */
 	const char *app;

Modified: team/kmoore/stasis_http_rename/res/ari/resource_playback.h
URL: http://svnview.digium.com/svn/asterisk/team/kmoore/stasis_http_rename/res/ari/resource_playback.h?view=diff&rev=395529&r1=395528&r2=395529
==============================================================================
--- team/kmoore/stasis_http_rename/res/ari/resource_asterisk.h (original)
+++ team/kmoore/stasis_http_rename/res/ari/resource_asterisk.h Fri Jul 26 12:59:18 2013
@@ -19,7 +19,7 @@
 /*! \file
  *
  * \brief Generated file - declares stubs to be implemented in
- * res/stasis_http/resource_asterisk.c
+ * res/ari/resource_asterisk.c
  *
  * Asterisk resources
  *
@@ -31,15 +31,15 @@
  * !!!!!                               DO NOT EDIT                        !!!!!
  * !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
  * This file is generated by a mustache template. Please see the original
- * template in rest-api-templates/stasis_http_resource.h.mustache
+ * template in rest-api-templates/ari_resource.h.mustache
  */
 
 #ifndef _ASTERISK_RESOURCE_ASTERISK_H
 #define _ASTERISK_RESOURCE_ASTERISK_H
 
-#include "asterisk/stasis_http.h"
+#include "asterisk/ari.h"
 
 /*! \brief Argument struct for stasis_http_get_asterisk_info() */
 struct ast_get_asterisk_info_args {
 	/*! \brief Filter information returned */
 	const char *only;
@@ -51,8 +51,8 @@
  * \param args Swagger parameters
  * \param[out] response HTTP response
  */
-void stasis_http_get_asterisk_info(struct ast_variable *headers, struct ast_get_asterisk_info_args *args, struct stasis_http_response *response);
-/*! \brief Argument struct for stasis_http_get_global_var() */
+void ari_get_asterisk_info(struct ast_variable *headers, struct ast_get_asterisk_info_args *args, struct ari_response *response);
+/*! \brief Argument struct for ari_get_global_var() */
 struct ast_get_global_var_args {
 	/*! \brief The variable to get */
 	const char *variable;
@@ -64,8 +64,8 @@
  * \param args Swagger parameters
  * \param[out] response HTTP response
  */
-void stasis_http_get_global_var(struct ast_variable *headers, struct ast_get_global_var_args *args, struct stasis_http_response *response);
-/*! \brief Argument struct for stasis_http_set_global_var() */
+void ari_get_global_var(struct ast_variable *headers, struct ast_get_global_var_args *args, struct ari_response *response);
+/*! \brief Argument struct for ari_set_global_var() */
 struct ast_set_global_var_args {
 	/*! \brief The variable to set */
 	const char *variable;
@@ -79,6 +79,6 @@
  * \param args Swagger parameters
  * \param[out] response HTTP response
  */
-void stasis_http_set_global_var(struct ast_variable *headers, struct ast_set_global_var_args *args, struct stasis_http_response *response);
+void ari_set_global_var(struct ast_variable *headers, struct ast_set_global_var_args *args, struct ari_response *response);
 
 #endif /* _ASTERISK_RESOURCE_ASTERISK_H */
@@ -31,15 +31,15 @@
 
-/*! \brief Argument struct for stasis_http_get_asterisk_info() */
+/*! \brief Argument struct for ari_get_asterisk_info() */
 struct ast_get_asterisk_info_args {
 	/*! \brief Filter information returned */

Modified: team/kmoore/stasis_http_rename/res/ari/resource_bridges.h
URL: http://svnview.digium.com/svn/asterisk/team/kmoore/stasis_http_rename/res/ari/resource_bridges.h?view=diff&rev=395529&r1=395528&r2=395529
==============================================================================
--- team/kmoore/stasis_http_rename/res/ari/resource_bridges.h (original)
+++ team/kmoore/stasis_http_rename/res/ari/resource_bridges.h Fri Jul 26 12:59:18 2013
@@ -19,7 +19,7 @@
 /*! \file
  *
  * \brief Generated file - declares stubs to be implemented in
- * res/stasis_http/resource_bridges.c
+ * res/ari/resource_bridges.c
  *
  * Bridge resources
  *
@@ -31,15 +31,15 @@
  * !!!!!                               DO NOT EDIT                        !!!!!
  * !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
  * This file is generated by a mustache template. Please see the original
- * template in rest-api-templates/stasis_http_resource.h.mustache
+ * template in rest-api-templates/ari_resource.h.mustache
  */
 
 #ifndef _ASTERISK_RESOURCE_BRIDGES_H
 #define _ASTERISK_RESOURCE_BRIDGES_H
 
-#include "asterisk/stasis_http.h"
+#include "asterisk/ari.h"
 
 /*! \brief Argument struct for stasis_http_get_bridges() */
 struct ast_get_bridges_args {
 };
 /*!
@@ -49,8 +49,8 @@
  * \param args Swagger parameters
  * \param[out] response HTTP response
  */
-void stasis_http_get_bridges(struct ast_variable *headers, struct ast_get_bridges_args *args, struct stasis_http_response *response);
-/*! \brief Argument struct for stasis_http_new_bridge() */
+void ari_get_bridges(struct ast_variable *headers, struct ast_get_bridges_args *args, struct ari_response *response);
+/*! \brief Argument struct for ari_new_bridge() */
 struct ast_new_bridge_args {
 	/*! \brief Type of bridge to create. */
 	const char *type;
@@ -64,8 +64,8 @@
  * \param args Swagger parameters
  * \param[out] response HTTP response
  */
-void stasis_http_new_bridge(struct ast_variable *headers, struct ast_new_bridge_args *args, struct stasis_http_response *response);
-/*! \brief Argument struct for stasis_http_get_bridge() */
+void ari_new_bridge(struct ast_variable *headers, struct ast_new_bridge_args *args, struct ari_response *response);
+/*! \brief Argument struct for ari_get_bridge() */
 struct ast_get_bridge_args {
 	/*! \brief Bridge's id */
 	const char *bridge_id;
@@ -77,8 +77,8 @@
  * \param args Swagger parameters
  * \param[out] response HTTP response
  */
-void stasis_http_get_bridge(struct ast_variable *headers, struct ast_get_bridge_args *args, struct stasis_http_response *response);
-/*! \brief Argument struct for stasis_http_delete_bridge() */
+void ari_get_bridge(struct ast_variable *headers, struct ast_get_bridge_args *args, struct ari_response *response);
+/*! \brief Argument struct for ari_delete_bridge() */
 struct ast_delete_bridge_args {
 	/*! \brief Bridge's id */
 	const char *bridge_id;
@@ -92,8 +92,8 @@
  * \param args Swagger parameters
  * \param[out] response HTTP response
  */
-void stasis_http_delete_bridge(struct ast_variable *headers, struct ast_delete_bridge_args *args, struct stasis_http_response *response);
-/*! \brief Argument struct for stasis_http_add_channel_to_bridge() */
+void ari_delete_bridge(struct ast_variable *headers, struct ast_delete_bridge_args *args, struct ari_response *response);
+/*! \brief Argument struct for ari_add_channel_to_bridge() */
 struct ast_add_channel_to_bridge_args {
 	/*! \brief Bridge's id */
 	const char *bridge_id;
@@ -107,8 +107,8 @@
  * \param args Swagger parameters
  * \param[out] response HTTP response
  */
-void stasis_http_add_channel_to_bridge(struct ast_variable *headers, struct ast_add_channel_to_bridge_args *args, struct stasis_http_response *response);
-/*! \brief Argument struct for stasis_http_remove_channel_from_bridge() */
+void ari_add_channel_to_bridge(struct ast_variable *headers, struct ast_add_channel_to_bridge_args *args, struct ari_response *response);
+/*! \brief Argument struct for ari_remove_channel_from_bridge() */
 struct ast_remove_channel_from_bridge_args {
 	/*! \brief Bridge's id */
 	const char *bridge_id;
@@ -122,8 +122,8 @@
  * \param args Swagger parameters
  * \param[out] response HTTP response
  */
-void stasis_http_remove_channel_from_bridge(struct ast_variable *headers, struct ast_remove_channel_from_bridge_args *args, struct stasis_http_response *response);
-/*! \brief Argument struct for stasis_http_play_on_bridge() */
+void ari_remove_channel_from_bridge(struct ast_variable *headers, struct ast_remove_channel_from_bridge_args *args, struct ari_response *response);
+/*! \brief Argument struct for ari_play_on_bridge() */
 struct ast_play_on_bridge_args {
 	/*! \brief Bridge's id */
 	const char *bridge_id;
@@ -145,8 +145,8 @@
  * \param args Swagger parameters
  * \param[out] response HTTP response
  */
-void stasis_http_play_on_bridge(struct ast_variable *headers, struct ast_play_on_bridge_args *args, struct stasis_http_response *response);
-/*! \brief Argument struct for stasis_http_record_bridge() */
+void ari_play_on_bridge(struct ast_variable *headers, struct ast_play_on_bridge_args *args, struct ari_response *response);
+/*! \brief Argument struct for ari_record_bridge() */
 struct ast_record_bridge_args {
 	/*! \brief Bridge's id */
 	const char *bridge_id;
@@ -174,6 +174,6 @@
  * \param args Swagger parameters
  * \param[out] response HTTP response
  */
-void stasis_http_record_bridge(struct ast_variable *headers, struct ast_record_bridge_args *args, struct stasis_http_response *response);
+void ari_record_bridge(struct ast_variable *headers, struct ast_record_bridge_args *args, struct ari_response *response);
 
 #endif /* _ASTERISK_RESOURCE_BRIDGES_H */
@@ -31,15 +31,15 @@
 
-/*! \brief Argument struct for stasis_http_get_bridges() */
+/*! \brief Argument struct for ari_get_bridges() */
 struct ast_get_bridges_args {
 };

Modified: team/kmoore/stasis_http_rename/res/ari/resource_channels.h
URL: http://svnview.digium.com/svn/asterisk/team/kmoore/stasis_http_rename/res/ari/resource_channels.h?view=diff&rev=395529&r1=395528&r2=395529
==============================================================================
--- team/kmoore/stasis_http_rename/res/ari/resource_channels.h (original)
+++ team/kmoore/stasis_http_rename/res/ari/resource_channels.h Fri Jul 26 12:59:18 2013
@@ -19,7 +19,7 @@
 /*! \file
  *
  * \brief Generated file - declares stubs to be implemented in
- * res/stasis_http/resource_channels.c
+ * res/ari/resource_channels.c
  *
  * Channel resources
  *
@@ -31,15 +31,15 @@
  * !!!!!                               DO NOT EDIT                        !!!!!
  * !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
  * This file is generated by a mustache template. Please see the original
- * template in rest-api-templates/stasis_http_resource.h.mustache
+ * template in rest-api-templates/ari_resource.h.mustache
  */
 
 #ifndef _ASTERISK_RESOURCE_CHANNELS_H
 #define _ASTERISK_RESOURCE_CHANNELS_H
 
-#include "asterisk/stasis_http.h"
-
-/*! \brief Argument struct for stasis_http_get_channels() */
+#include "asterisk/ari.h"
+
+/*! \brief Argument struct for ari_get_channels() */
 struct ast_get_channels_args {
 };
 /*!
@@ -49,8 +49,8 @@
  * \param args Swagger parameters
  * \param[out] response HTTP response
  */
-void stasis_http_get_channels(struct ast_variable *headers, struct ast_get_channels_args *args, struct stasis_http_response *response);
-/*! \brief Argument struct for stasis_http_originate() */
+void ari_get_channels(struct ast_variable *headers, struct ast_get_channels_args *args, struct ari_response *response);
+/*! \brief Argument struct for ari_originate() */
 struct ast_originate_args {
 	/*! \brief Endpoint to call. */
 	const char *endpoint;
@@ -76,8 +76,8 @@
  * \param args Swagger parameters
  * \param[out] response HTTP response
  */
-void stasis_http_originate(struct ast_variable *headers, struct ast_originate_args *args, struct stasis_http_response *response);
-/*! \brief Argument struct for stasis_http_get_channel() */
+void ari_originate(struct ast_variable *headers, struct ast_originate_args *args, struct ari_response *response);
+/*! \brief Argument struct for ari_get_channel() */
 struct ast_get_channel_args {
 	/*! \brief Channel's id */
 	const char *channel_id;
@@ -89,8 +89,8 @@
  * \param args Swagger parameters
  * \param[out] response HTTP response
  */
-void stasis_http_get_channel(struct ast_variable *headers, struct ast_get_channel_args *args, struct stasis_http_response *response);
-/*! \brief Argument struct for stasis_http_delete_channel() */
+void ari_get_channel(struct ast_variable *headers, struct ast_get_channel_args *args, struct ari_response *response);
+/*! \brief Argument struct for ari_delete_channel() */
 struct ast_delete_channel_args {
 	/*! \brief Channel's id */
 	const char *channel_id;
@@ -102,8 +102,8 @@
  * \param args Swagger parameters
  * \param[out] response HTTP response
  */
-void stasis_http_delete_channel(struct ast_variable *headers, struct ast_delete_channel_args *args, struct stasis_http_response *response);
-/*! \brief Argument struct for stasis_http_dial() */
+void ari_delete_channel(struct ast_variable *headers, struct ast_delete_channel_args *args, struct ari_response *response);
+/*! \brief Argument struct for ari_dial() */
 struct ast_dial_args {
 	/*! \brief Channel's id */
 	const char *channel_id;
@@ -123,8 +123,8 @@
  * \param args Swagger parameters
  * \param[out] response HTTP response
  */
-void stasis_http_dial(struct ast_variable *headers, struct ast_dial_args *args, struct stasis_http_response *response);
-/*! \brief Argument struct for stasis_http_continue_in_dialplan() */
+void ari_dial(struct ast_variable *headers, struct ast_dial_args *args, struct ari_response *response);
+/*! \brief Argument struct for ari_continue_in_dialplan() */
 struct ast_continue_in_dialplan_args {
 	/*! \brief Channel's id */
 	const char *channel_id;
@@ -142,8 +142,8 @@
  * \param args Swagger parameters
  * \param[out] response HTTP response
  */
-void stasis_http_continue_in_dialplan(struct ast_variable *headers, struct ast_continue_in_dialplan_args *args, struct stasis_http_response *response);
-/*! \brief Argument struct for stasis_http_answer_channel() */
+void ari_continue_in_dialplan(struct ast_variable *headers, struct ast_continue_in_dialplan_args *args, struct ari_response *response);
+/*! \brief Argument struct for ari_answer_channel() */
 struct ast_answer_channel_args {
 	/*! \brief Channel's id */
 	const char *channel_id;
@@ -155,8 +155,8 @@
  * \param args Swagger parameters
  * \param[out] response HTTP response
  */
-void stasis_http_answer_channel(struct ast_variable *headers, struct ast_answer_channel_args *args, struct stasis_http_response *response);
-/*! \brief Argument struct for stasis_http_mute_channel() */
+void ari_answer_channel(struct ast_variable *headers, struct ast_answer_channel_args *args, struct ari_response *response);
+/*! \brief Argument struct for ari_mute_channel() */
 struct ast_mute_channel_args {
 	/*! \brief Channel's id */
 	const char *channel_id;
@@ -170,8 +170,8 @@
  * \param args Swagger parameters
  * \param[out] response HTTP response
  */
-void stasis_http_mute_channel(struct ast_variable *headers, struct ast_mute_channel_args *args, struct stasis_http_response *response);
-/*! \brief Argument struct for stasis_http_unmute_channel() */
+void ari_mute_channel(struct ast_variable *headers, struct ast_mute_channel_args *args, struct ari_response *response);
+/*! \brief Argument struct for ari_unmute_channel() */
 struct ast_unmute_channel_args {
 	/*! \brief Channel's id */
 	const char *channel_id;
@@ -185,8 +185,8 @@
  * \param args Swagger parameters
  * \param[out] response HTTP response
  */
-void stasis_http_unmute_channel(struct ast_variable *headers, struct ast_unmute_channel_args *args, struct stasis_http_response *response);
-/*! \brief Argument struct for stasis_http_hold_channel() */
+void ari_unmute_channel(struct ast_variable *headers, struct ast_unmute_channel_args *args, struct ari_response *response);
+/*! \brief Argument struct for ari_hold_channel() */
 struct ast_hold_channel_args {
 	/*! \brief Channel's id */
 	const char *channel_id;
@@ -198,8 +198,8 @@
  * \param args Swagger parameters
  * \param[out] response HTTP response
  */
-void stasis_http_hold_channel(struct ast_variable *headers, struct ast_hold_channel_args *args, struct stasis_http_response *response);
-/*! \brief Argument struct for stasis_http_unhold_channel() */
+void ari_hold_channel(struct ast_variable *headers, struct ast_hold_channel_args *args, struct ari_response *response);
+/*! \brief Argument struct for ari_unhold_channel() */
 struct ast_unhold_channel_args {
 	/*! \brief Channel's id */
 	const char *channel_id;
@@ -211,8 +211,8 @@
  * \param args Swagger parameters
  * \param[out] response HTTP response
  */
-void stasis_http_unhold_channel(struct ast_variable *headers, struct ast_unhold_channel_args *args, struct stasis_http_response *response);
-/*! \brief Argument struct for stasis_http_moh_start_channel() */
+void ari_unhold_channel(struct ast_variable *headers, struct ast_unhold_channel_args *args, struct ari_response *response);
+/*! \brief Argument struct for ari_moh_start_channel() */
 struct ast_moh_start_channel_args {
 	/*! \brief Channel's id */
 	const char *channel_id;
@@ -228,8 +228,8 @@
  * \param args Swagger parameters
  * \param[out] response HTTP response
  */
-void stasis_http_moh_start_channel(struct ast_variable *headers, struct ast_moh_start_channel_args *args, struct stasis_http_response *response);
-/*! \brief Argument struct for stasis_http_moh_stop_channel() */
+void ari_moh_start_channel(struct ast_variable *headers, struct ast_moh_start_channel_args *args, struct ari_response *response);
+/*! \brief Argument struct for ari_moh_stop_channel() */
 struct ast_moh_stop_channel_args {
 	/*! \brief Channel's id */
 	const char *channel_id;
@@ -241,8 +241,8 @@
  * \param args Swagger parameters
  * \param[out] response HTTP response
  */
-void stasis_http_moh_stop_channel(struct ast_variable *headers, struct ast_moh_stop_channel_args *args, struct stasis_http_response *response);
-/*! \brief Argument struct for stasis_http_play_on_channel() */
+void ari_moh_stop_channel(struct ast_variable *headers, struct ast_moh_stop_channel_args *args, struct ari_response *response);
+/*! \brief Argument struct for ari_play_on_channel() */
 struct ast_play_on_channel_args {
 	/*! \brief Channel's id */
 	const char *channel_id;
@@ -264,8 +264,8 @@
  * \param args Swagger parameters
  * \param[out] response HTTP response
  */
-void stasis_http_play_on_channel(struct ast_variable *headers, struct ast_play_on_channel_args *args, struct stasis_http_response *response);
-/*! \brief Argument struct for stasis_http_record_channel() */
+void ari_play_on_channel(struct ast_variable *headers, struct ast_play_on_channel_args *args, struct ari_response *response);
+/*! \brief Argument struct for ari_record_channel() */
 struct ast_record_channel_args {
 	/*! \brief Channel's id */
 	const char *channel_id;
@@ -293,8 +293,8 @@
  * \param args Swagger parameters
  * \param[out] response HTTP response
  */
-void stasis_http_record_channel(struct ast_variable *headers, struct ast_record_channel_args *args, struct stasis_http_response *response);
-/*! \brief Argument struct for stasis_http_get_channel_var() */
+void ari_record_channel(struct ast_variable *headers, struct ast_record_channel_args *args, struct ari_response *response);
+/*! \brief Argument struct for ari_get_channel_var() */
 struct ast_get_channel_var_args {
 	/*! \brief Channel's id */
 	const char *channel_id;
@@ -308,8 +308,8 @@
  * \param args Swagger parameters
  * \param[out] response HTTP response
  */
-void stasis_http_get_channel_var(struct ast_variable *headers, struct ast_get_channel_var_args *args, struct stasis_http_response *response);
-/*! \brief Argument struct for stasis_http_set_channel_var() */
+void ari_get_channel_var(struct ast_variable *headers, struct ast_get_channel_var_args *args, struct ari_response *response);
+/*! \brief Argument struct for ari_set_channel_var() */
 struct ast_set_channel_var_args {
 	/*! \brief Channel's id */
 	const char *channel_id;
@@ -325,6 +325,6 @@
  * \param args Swagger parameters
  * \param[out] response HTTP response
  */
-void stasis_http_set_channel_var(struct ast_variable *headers, struct ast_set_channel_var_args *args, struct stasis_http_response *response);
+void ari_set_channel_var(struct ast_variable *headers, struct ast_set_channel_var_args *args, struct ari_response *response);
 
 #endif /* _ASTERISK_RESOURCE_CHANNELS_H */

Modified: team/kmoore/stasis_http_rename/res/ari/resource_endpoints.h
URL: http://svnview.digium.com/svn/asterisk/team/kmoore/stasis_http_rename/res/ari/resource_endpoints.h?view=diff&rev=395529&r1=395528&r2=395529
==============================================================================
--- team/kmoore/stasis_http_rename/res/ari/resource_endpoints.h (original)
+++ team/kmoore/stasis_http_rename/res/ari/resource_endpoints.h Fri Jul 26 12:59:18 2013
@@ -19,7 +19,7 @@
 /*! \file
  *
  * \brief Generated file - declares stubs to be implemented in
- * res/stasis_http/resource_endpoints.c
+ * res/ari/resource_endpoints.c
  *
  * Endpoint resources
  *
@@ -31,15 +31,15 @@
  * !!!!!                               DO NOT EDIT                        !!!!!
  * !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
  * This file is generated by a mustache template. Please see the original
- * template in rest-api-templates/stasis_http_resource.h.mustache
+ * template in rest-api-templates/ari_resource.h.mustache
  */
 
 #ifndef _ASTERISK_RESOURCE_ENDPOINTS_H
 #define _ASTERISK_RESOURCE_ENDPOINTS_H
 
-#include "asterisk/stasis_http.h"
+#include "asterisk/ari.h"
 
 /*! \brief Argument struct for stasis_http_get_endpoints() */
 struct ast_get_endpoints_args {
 };
 /*!
@@ -49,8 +49,8 @@
  * \param args Swagger parameters
  * \param[out] response HTTP response
  */
-void stasis_http_get_endpoints(struct ast_variable *headers, struct ast_get_endpoints_args *args, struct stasis_http_response *response);
-/*! \brief Argument struct for stasis_http_get_endpoints_by_tech() */
+void ari_get_endpoints(struct ast_variable *headers, struct ast_get_endpoints_args *args, struct ari_response *response);
+/*! \brief Argument struct for ari_get_endpoints_by_tech() */
 struct ast_get_endpoints_by_tech_args {
 	/*! \brief Technology of the endpoints (sip,iax2,...) */
 	const char *tech;
@@ -62,8 +62,8 @@
  * \param args Swagger parameters
  * \param[out] response HTTP response
  */
-void stasis_http_get_endpoints_by_tech(struct ast_variable *headers, struct ast_get_endpoints_by_tech_args *args, struct stasis_http_response *response);
-/*! \brief Argument struct for stasis_http_get_endpoint() */
+void ari_get_endpoints_by_tech(struct ast_variable *headers, struct ast_get_endpoints_by_tech_args *args, struct ari_response *response);
+/*! \brief Argument struct for ari_get_endpoint() */
 struct ast_get_endpoint_args {
 	/*! \brief Technology of the endpoint */
 	const char *tech;
@@ -77,6 +77,6 @@
  * \param args Swagger parameters
  * \param[out] response HTTP response
  */
-void stasis_http_get_endpoint(struct ast_variable *headers, struct ast_get_endpoint_args *args, struct stasis_http_response *response);
+void ari_get_endpoint(struct ast_variable *headers, struct ast_get_endpoint_args *args, struct ari_response *response);
 
 #endif /* _ASTERISK_RESOURCE_ENDPOINTS_H */
@@ -31,15 +31,15 @@
 
-/*! \brief Argument struct for stasis_http_get_endpoints() */
+/*! \brief Argument struct for ari_get_endpoints() */
 struct ast_get_endpoints_args {
 };

Modified: team/kmoore/stasis_http_rename/res/ari/resource_events.h
URL: http://svnview.digium.com/svn/asterisk/team/kmoore/stasis_http_rename/res/ari/resource_events.h?view=diff&rev=395529&r1=395528&r2=395529
==============================================================================
--- team/kmoore/stasis_http_rename/res/ari/resource_playback.h (original)
+++ team/kmoore/stasis_http_rename/res/ari/resource_playback.h Fri Jul 26 12:59:18 2013
@@ -19,7 +19,7 @@
 /*! \file
  *
  * \brief Generated file - declares stubs to be implemented in
- * res/stasis_http/resource_playback.c
+ * res/ari/resource_playback.c
  *
  * Playback control resources
  *
@@ -31,15 +31,15 @@
  * !!!!!                               DO NOT EDIT                        !!!!!
  * !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
  * This file is generated by a mustache template. Please see the original
- * template in rest-api-templates/stasis_http_resource.h.mustache
+ * template in rest-api-templates/ari_resource.h.mustache
  */
 
 #ifndef _ASTERISK_RESOURCE_PLAYBACK_H
 #define _ASTERISK_RESOURCE_PLAYBACK_H
 
-#include "asterisk/stasis_http.h"
+#include "asterisk/ari.h"
 
 /*! \brief Argument struct for stasis_http_get_playback() */
 struct ast_get_playback_args {
 	/*! \brief Playback's id */
 	const char *playback_id;
@@ -51,8 +51,8 @@
  * \param args Swagger parameters
  * \param[out] response HTTP response
  */
-void stasis_http_get_playback(struct ast_variable *headers, struct ast_get_playback_args *args, struct stasis_http_response *response);
-/*! \brief Argument struct for stasis_http_stop_playback() */
+void ari_get_playback(struct ast_variable *headers, struct ast_get_playback_args *args, struct ari_response *response);
+/*! \brief Argument struct for ari_stop_playback() */
 struct ast_stop_playback_args {
 	/*! \brief Playback's id */
 	const char *playback_id;
@@ -64,8 +64,8 @@
  * \param args Swagger parameters
  * \param[out] response HTTP response
  */
-void stasis_http_stop_playback(struct ast_variable *headers, struct ast_stop_playback_args *args, struct stasis_http_response *response);
-/*! \brief Argument struct for stasis_http_control_playback() */
+void ari_stop_playback(struct ast_variable *headers, struct ast_stop_playback_args *args, struct ari_response *response);
+/*! \brief Argument struct for ari_control_playback() */
 struct ast_control_playback_args {
 	/*! \brief Playback's id */
 	const char *playback_id;
@@ -79,6 +79,6 @@
  * \param args Swagger parameters
  * \param[out] response HTTP response
  */
-void stasis_http_control_playback(struct ast_variable *headers, struct ast_control_playback_args *args, struct stasis_http_response *response);
+void ari_control_playback(struct ast_variable *headers, struct ast_control_playback_args *args, struct ari_response *response);
 
 #endif /* _ASTERISK_RESOURCE_PLAYBACK_H */
@@ -31,15 +31,15 @@
 
-/*! \brief Argument struct for stasis_http_get_playback() */
+/*! \brief Argument struct for ari_get_playback() */
 struct ast_get_playback_args {
 	/*! \brief Playback's id */

Modified: team/kmoore/stasis_http_rename/res/ari/resource_recordings.h
URL: http://svnview.digium.com/svn/asterisk/team/kmoore/stasis_http_rename/res/ari/resource_recordings.h?view=diff&rev=395529&r1=395528&r2=395529
==============================================================================
--- team/kmoore/stasis_http_rename/res/ari/resource_recordings.h (original)
+++ team/kmoore/stasis_http_rename/res/ari/resource_recordings.h Fri Jul 26 12:59:18 2013
@@ -19,7 +19,7 @@
 /*! \file
  *
  * \brief Generated file - declares stubs to be implemented in
- * res/stasis_http/resource_recordings.c
+ * res/ari/resource_recordings.c
  *
  * Recording resources
  *
@@ -31,15 +31,15 @@
  * !!!!!                               DO NOT EDIT                        !!!!!
  * !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
  * This file is generated by a mustache template. Please see the original
- * template in rest-api-templates/stasis_http_resource.h.mustache
+ * template in rest-api-templates/ari_resource.h.mustache
  */
 
 #ifndef _ASTERISK_RESOURCE_RECORDINGS_H
 #define _ASTERISK_RESOURCE_RECORDINGS_H
 
-#include "asterisk/stasis_http.h"
+#include "asterisk/ari.h"
 
 /*! \brief Argument struct for stasis_http_get_stored_recordings() */
 struct ast_get_stored_recordings_args {
 };
 /*!
@@ -49,8 +49,8 @@
  * \param args Swagger parameters
  * \param[out] response HTTP response
  */
-void stasis_http_get_stored_recordings(struct ast_variable *headers, struct ast_get_stored_recordings_args *args, struct stasis_http_response *response);
-/*! \brief Argument struct for stasis_http_get_stored_recording() */
+void ari_get_stored_recordings(struct ast_variable *headers, struct ast_get_stored_recordings_args *args, struct ari_response *response);
+/*! \brief Argument struct for ari_get_stored_recording() */
 struct ast_get_stored_recording_args {
 	/*! \brief The name of the recording */
 	const char *recording_name;
@@ -62,8 +62,8 @@
  * \param args Swagger parameters
  * \param[out] response HTTP response
  */
-void stasis_http_get_stored_recording(struct ast_variable *headers, struct ast_get_stored_recording_args *args, struct stasis_http_response *response);
-/*! \brief Argument struct for stasis_http_delete_stored_recording() */
+void ari_get_stored_recording(struct ast_variable *headers, struct ast_get_stored_recording_args *args, struct ari_response *response);
+/*! \brief Argument struct for ari_delete_stored_recording() */
 struct ast_delete_stored_recording_args {
 	/*! \brief The name of the recording */
 	const char *recording_name;
@@ -75,8 +75,8 @@
  * \param args Swagger parameters
  * \param[out] response HTTP response
  */
-void stasis_http_delete_stored_recording(struct ast_variable *headers, struct ast_delete_stored_recording_args *args, struct stasis_http_response *response);
-/*! \brief Argument struct for stasis_http_get_live_recordings() */
+void ari_delete_stored_recording(struct ast_variable *headers, struct ast_delete_stored_recording_args *args, struct ari_response *response);
+/*! \brief Argument struct for ari_get_live_recordings() */
 struct ast_get_live_recordings_args {
 };
 /*!
@@ -86,8 +86,8 @@
  * \param args Swagger parameters
  * \param[out] response HTTP response
  */
-void stasis_http_get_live_recordings(struct ast_variable *headers, struct ast_get_live_recordings_args *args, struct stasis_http_response *response);
-/*! \brief Argument struct for stasis_http_get_live_recording() */
+void ari_get_live_recordings(struct ast_variable *headers, struct ast_get_live_recordings_args *args, struct ari_response *response);
+/*! \brief Argument struct for ari_get_live_recording() */
 struct ast_get_live_recording_args {
 	/*! \brief The name of the recording */
 	const char *recording_name;
@@ -99,8 +99,8 @@
  * \param args Swagger parameters
  * \param[out] response HTTP response
  */
-void stasis_http_get_live_recording(struct ast_variable *headers, struct ast_get_live_recording_args *args, struct stasis_http_response *response);
-/*! \brief Argument struct for stasis_http_cancel_recording() */
+void ari_get_live_recording(struct ast_variable *headers, struct ast_get_live_recording_args *args, struct ari_response *response);
+/*! \brief Argument struct for ari_cancel_recording() */
 struct ast_cancel_recording_args {
 	/*! \brief The name of the recording */
 	const char *recording_name;
@@ -112,8 +112,8 @@
  * \param args Swagger parameters
  * \param[out] response HTTP response
  */
-void stasis_http_cancel_recording(struct ast_variable *headers, struct ast_cancel_recording_args *args, struct stasis_http_response *response);
-/*! \brief Argument struct for stasis_http_stop_recording() */
+void ari_cancel_recording(struct ast_variable *headers, struct ast_cancel_recording_args *args, struct ari_response *response);
+/*! \brief Argument struct for ari_stop_recording() */
 struct ast_stop_recording_args {
 	/*! \brief The name of the recording */
 	const char *recording_name;
@@ -125,8 +125,8 @@
  * \param args Swagger parameters
  * \param[out] response HTTP response
  */
-void stasis_http_stop_recording(struct ast_variable *headers, struct ast_stop_recording_args *args, struct stasis_http_response *response);
-/*! \brief Argument struct for stasis_http_pause_recording() */
+void ari_stop_recording(struct ast_variable *headers, struct ast_stop_recording_args *args, struct ari_response *response);
+/*! \brief Argument struct for ari_pause_recording() */
 struct ast_pause_recording_args {
 	/*! \brief The name of the recording */
 	const char *recording_name;
@@ -140,8 +140,8 @@
  * \param args Swagger parameters
  * \param[out] response HTTP response
  */
-void stasis_http_pause_recording(struct ast_variable *headers, struct ast_pause_recording_args *args, struct stasis_http_response *response);
-/*! \brief Argument struct for stasis_http_unpause_recording() */
+void ari_pause_recording(struct ast_variable *headers, struct ast_pause_recording_args *args, struct ari_response *response);
+/*! \brief Argument struct for ari_unpause_recording() */
 struct ast_unpause_recording_args {
 	/*! \brief The name of the recording */
 	const char *recording_name;
@@ -153,8 +153,8 @@
  * \param args Swagger parameters
  * \param[out] response HTTP response
  */
-void stasis_http_unpause_recording(struct ast_variable *headers, struct ast_unpause_recording_args *args, struct stasis_http_response *response);
-/*! \brief Argument struct for stasis_http_mute_recording() */
+void ari_unpause_recording(struct ast_variable *headers, struct ast_unpause_recording_args *args, struct ari_response *response);
+/*! \brief Argument struct for ari_mute_recording() */
 struct ast_mute_recording_args {
 	/*! \brief The name of the recording */
 	const char *recording_name;
@@ -168,8 +168,8 @@
  * \param args Swagger parameters
  * \param[out] response HTTP response
  */
-void stasis_http_mute_recording(struct ast_variable *headers, struct ast_mute_recording_args *args, struct stasis_http_response *response);
-/*! \brief Argument struct for stasis_http_unmute_recording() */
+void ari_mute_recording(struct ast_variable *headers, struct ast_mute_recording_args *args, struct ari_response *response);
+/*! \brief Argument struct for ari_unmute_recording() */
 struct ast_unmute_recording_args {
@@ -31,15 +31,15 @@
 
-/*! \brief Argument struct for stasis_http_get_stored_recordings() */
+/*! \brief Argument struct for ari_get_stored_recordings() */
 struct ast_get_stored_recordings_args {
 };

[... 2356 lines stripped ...]



More information about the svn-commits mailing list